package jrummikub.view;

import jrummikub.model.Position;
import jrummikub.model.StoneSet;
import jrummikub.util.Event1;
import jrummikub.util.Pair;

/**
 * The view of the table, where the stone sets lie
 */
public interface ITablePanel extends IStonePanel, IClickable {
	/**
	 * Sets the player name on the left label
	 * 
	 * @param playerName
	 *          the name to set
	 */
	public void setLeftPlayerName(String playerName);

	/**
	 * Sets the player name on the top label
	 * 
	 * @param playerName
	 *          the name to set
	 */
	public void setTopPlayerName(String playerName);

	/**
	 * Sets the player name on the right label
	 * 
	 * @param playerName
	 *          the name to set
	 */
	public void setRightPlayerName(String playerName);

	/**
	 * Sets the stone sets lying on the table
	 * 
	 * @param stoneSets
	 *          set stone sets on the table
	 */
	public void setStoneSets(Iterable<Pair<StoneSet, Position>> stoneSets);

	/**
	 * Returns the stone collection (the panel showing the stones currently
	 * selected)
	 * 
	 * @return the stone collection
	 */
	public IStoneCollectionPanel getStoneCollectionPanel();

	/**
	 * the left connector click event is emitted when the player clicks on a left
	 * connector of a stone set on the table .
	 * 
	 * @return the event
	 */
	public Event1<StoneSet> getLeftConnectorClickEvent();

	/**
	 * the right connector click event is emitted when the player clicks on a
	 * right connector of a stone set on the table .
	 * 
	 * @return the event
	 */
	public Event1<StoneSet> getRightConnectorClickEvent();
}
